# SOM Toolkit
Das SOM Toolkit ist ein Werkzeug, welches dem/der Benutzer:in ermöglichen soll, schnell Datenstrukturen für BIM Modelle zu beschreiben<br> und daraus verschiedene Vorlagen für Softwaretools zu generieren. <br>
das SOM-Toolkit ist eine graphische erweiterung des [SOMcreators](https://github.com/c-mellueh/SOMcreator).<br>
Hauptfokus liegt hierbei vor allem auf der semantischen Modellprüfung in Desite MD Pro. <br>
<br>

Nach Start des Programms gelangt man in den [MainView](https://github.com/c-mellueh/desiteRuleCreator/wiki/Windows#mainview):
![grafik](https://user-images.githubusercontent.com/74136980/194853307-d520a29a-b5cd-456f-9fb2-6886eaee69f0.png)
Von dort aus lassen sich Objekte und PropertySets bearbeiten. <br>
Das [Wiki](https://github.com/c-mellueh/desiteRuleCreator/wiki) ist noch im Aufbau, hält aber schon einige Informationen parat.


